@@ -16,7 +16,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::QuickTime;
 
-$VERSION = '1.02';
+$VERSION = '1.10';
 
 sub ProcessGoPro($$$);
 sub ProcessString($$$);
@@ -65,20 +65,26 @@ my %addUnits = (
     PROCESS_PROC => \&ProcessGoPro,
     GROUPS => { 2 => 'Camera' },
     NOTES => q{
-        Tags extracted from the GPMF box of GoPro MP4 videos, the APP6 "GoPro" segment
-        of JPEG files, and from the "gpmd" timed metadata if the L<ExtractEmbedded|../ExifTool.html#ExtractEmbedded> option
-        is enabled.  Many more tags exist, but are currently unknown and extracted only
-        with the L<Unknown|../ExifTool.html#Unknown> (-u) option. Please let me know if you discover the meaning of any of
-        these unknown tags. See L<https://github.com/gopro/gpmf-parser> for details
-        about this format.
+        Tags extracted from the GPMF box of GoPro MP4 videos, the APP6 "GoPro"
+        segment of JPEG files, and from the "gpmd" timed metadata if the
+        L<ExtractEmbedded|../ExifTool.html#ExtractEmbedded> (-ee) option is enabled.  Many more tags exist, but are
+        currently unknown and extracted only with the L<Unknown|../ExifTool.html#Unknown> (-u) option. Please
+        let me know if you discover the meaning of any of these unknown tags. See
+        L<https://github.com/gopro/gpmf-parser> for details about this format.
     },
+  # ABSC (GPMF) - seen: 0 (fmt f)
     ACCL => { #2 (gpmd)
         Name => 'Accelerometer',
         Notes => 'accelerator readings in m/s2',
         Binary => 1,
     },
+  # ANGX (GPMF-GEOC) - seen -0.05 (fmt d, Max)
+  # ANGY (GPMF-GEOC) - seen 179.9 (fmt d, Max)
+  # ANGZ (GPMF-GEOC) - seen 0.152 (fmt d, Max)
     ALLD => 'AutoLowLightDuration', #1 (gpmd) (untested)
-  # APTO (GPMF) - seen: 'RAW' (fmt c)
+  # APTO (GPMF) - seen: 'OFF', 'RAW', 'DYNM' (fmt c)
+  # ARUW (GPMF) - seen: 1.14285719394684 (fmt f)
+  # ARWA (GPMF) - seen: 1.14285719394684 (fmt f)
     ATTD => { #PH (Karma)
         Name => 'Attitude',
         # UNIT=s,rad,rad,rad,rad/s,rad/s,rad/s,
@@ -93,8 +99,10 @@ my %addUnits = (
         # SCAL=1000 1 1 1 1
         Binary => 1,
     },
+  # AUBT (GPMF) - seen: ''N' (type c)
     AUDO => 'AudioSetting', #PH (GPMF - seen: 'WIND', fmt c)
-  # AUPT (GPMF) - seen: 'N' (fmt c)
+  # AUPT (GPMF) - seen: 'N','Y' (fmt c)
+  # BITR (GPMF) - seen: 'STANDARD' (fmt c)
     BPOS => { #PH (Karma)
         Name => 'Controller',
         Unknown => 1,
@@ -104,17 +112,22 @@ my %addUnits = (
         %addUnits,
     },
   # BRID (GPMF) - seen: 0 (fmt B)
-  # BROD (GPMF) - seen: 'ASK' (fmt c)
+  # BROD (GPMF) - seen: 'ASK','' (fmt c)
+  # CALH (GPMF-GEOC) - seen 3040 (fmt L, Max)
+  # CALW (GPMF-GEOC) - seen 4056 (fmt L, Max)
     CASN => 'CameraSerialNumber', #PH (GPMF - seen: 'C3221324545448', fmt c)
-  # CINF (GPMF) - seen: 0x67376be7709bc8876a8baf3940908618 (fmt B)
-  # CMOD (GPMF) - seen: 12,13,17 [13 time-laps video, 17 JPEG] (fmt B)
-    CYTS => { #PH (Karma)
-        Name => 'CoyoteStatus',
-        # UNIT=s,,,,,rad,rad,rad,,
-        # TYPE=LLLLLfffBB
-        # SCAL=1000 1 1 1 1 1 1 1 1 1
-        Binary => 1,
-    },
+  # CDAT (GPMF) - seen: 1732152823 (fmt J)
+  # CDTM (GPMF) - seen: 0 (fmt L)
+  # CINF (GPMF) - seen: 0x67376be7709bc8876a8baf3940908618, 0xe230988539b30cf5f016627ae8fc5395,
+  #                     0x8bcbe424acc5b37d7d77001635198b3b (fmt B) (Camera INFormation?)
+  # CLDP (GPMF) - seen: 'Y' (fmt c)
+  # CLKC (GPMF) - seen: 0 (fmt L)
+  # CLKS (GPMF) - seen: 2 (fmt B)
+  # CMOD (GPMF) - seen: 12,13,17 [12 360 video, 13 time-laps video, 17 JPEG] (fmt B)
+  # CPID (GPMF) - seen: '1194885996 3387225026 733916448 2433577768' (fmt L)
+  # CPIN (GPMF) - seen: 1
+  # CRTX (GPMF-BACK/FRNT) - double[1]
+  # CRTY (GPMF-BACK/FRNT) - double[1]
     CSEN => { #PH (Karma)
         Name => 'CoyoteSense',
         # UNIT=s,rad/s,rad/s,rad/s,g,g,g,,,,
@@ -122,22 +135,42 @@ my %addUnits = (
         # SCAL=1000 1 1 1 1 1 1 1 1 1 1
         Binary => 1,
     },
+  # CTRL (GPMF) - seen: 'Pro' (fmt c)
+    CYTS => { #PH (Karma)
+        Name => 'CoyoteStatus',
+        # UNIT=s,,,,,rad,rad,rad,,
+        # TYPE=LLLLLfffBB
+        # SCAL=1000 1 1 1 1 1 1 1 1 1
+        Binary => 1,
+    },
     DEVC => { #PH (gpmd,GPMF, fmt \0)
         Name => 'DeviceContainer',
         SubDirectory => { TagTable => 'Image::ExifTool::GoPro::GPMF' },
+        # (Max) DVID=1,DVNM='Global Settings',VERS,FMWR,LINF,CINF,CASN,MINF,MUID,CMOD,MTYP,OREN,
+        #       DZOM,DZST,SMTR,PRTN,PTWB,PTSH,PTCL,EXPT,PIMX,PIMN,PTEV,RATE,SROT,ZFOV,VLTE,VLTA,
+        #       EISE,EISA,AUPT,AUDO,BROD,BRID,PVUL,PRJT,SOFF
+        # (Max) DVID='GEOC',DVNM='Geometry Calibrations',SHFX,SHFY,SHFZ,ANGX,ANGY,ANGZ,CALW,CALH
+        # (Max) DVID='BACK',DVNM='Back Lens',KLNS,CTRX,CTRY,MFOV,SFTR
+        # (Max) DVID='FRNT',DVNM='Front Lens',KLNS,CTRX,CTRY,MFOV,SFTR
+        # (Max) DVID='HLMT',DVNM='Highlights'
     },
-  # DVID (GPMF) - DeviceID; seen: 1 (fmt L), HLMT (fmt F)
+  # DNSC (GPMF) - seen: 'HIGH' (fmt c)
+  # DUST (GPMF) - seen: 'NO_LIMIT' (fmt c)
+  # DVID (GPMF) - DeviceID; seen: 1 (fmt L), HLMT (fmt F), GEOC (fmt F), 'BACK' (fmt F, Max)
     DVID => { Name => 'DeviceID', Unknown => 1 }, #2 (gpmd)
-  # DVNM (GPMF) seen: 'Video Global Settings' (fmt c), 'Highlights' (fmt c)
+  # DVNM (GPMF) seen: 'Video Global Settings' (fmt c), 'Highlights' (fmt c), 'Geometry Calibrations' (Max)
   # DVNM (gpmd) seen: 'Camera' (Hero5), 'Hero6 Black' (Hero6), 'GoPro Karma v1.0' (Karma)
-    DVNM => 'DeviceName', #PH
+    DVNM => 'DeviceName', #PH (n/c)
     DZOM => { #PH (GPMF - seen: 'Y', fmt c)
         Name => 'DigitalZoom',
         PrintConv => { N => 'No', Y => 'Yes' },
     },
+  # DZMX (GPMF) - seen: 1.39999997615814 (fmt f)
   # DZST (GPMF) - seen: 0 (fmt L) (something to do with digital zoom maybe?)
-  # EISA (GPMF) - seen: 'Y','N' [N was for a time-lapse video] (fmt c)
-  # EISE (GPMF) - seen: 'Y' (fmt c)
+    EISA => { #PH (GPMF) - seen: 'Y','N','HS EIS','N/A' (fmt c) [N was for a time-lapse video]
+        Name => 'ElectronicImageStabilization',
+    },
+  # EISE (GPMF) - seen: 'Y','N' (fmt c)
     EMPT => { Name => 'Empty', Unknown => 1 }, #2 (gpmd)
     ESCS => { #PH (Karma)
         Name => 'EscapeStatus',
@@ -147,7 +180,7 @@ my %addUnits = (
         Unknown => 1,
         %addUnits,
     },
-  # EXPT (GPMF) - seen: '' (fmt c)
+  # EXPT (GPMF) - seen: '', 'AUTO' (fmt c)
     FACE => 'FaceDetected', #PH (gpmd)
     FCNM => 'FaceNumbers', #PH (gpmd) (faces counted per frame, ref 1)
     FMWR => 'FirmwareVersion', #PH (GPMF - seen: HD6.01.01.51.00, fmt c)
@@ -171,10 +204,20 @@ my %addUnits = (
     },
     GPS5 => { #2 (gpmd)
         Name => 'GPSInfo',
+        # UNIT=deg,deg,m,m/s,m/s
+        # TYPE=l
         # SCAL=10000000,10000000,1000,1000,100
         RawConv => '$val', # necessary to use scaled value instead of raw data as subdir data
         SubDirectory => { TagTable => 'Image::ExifTool::GoPro::GPS5' },
     },
+    GPS9 => { #PH (gpmd, Hero 13)
+        Name => 'GPSInfo9',
+        # UNIT=deg,deg,m,m/s,m/s,,s,,
+        # TYPE=lllllllSS
+        # SCAL=10000000 10000000 1000 1000 100 1 1000 100 1
+        RawConv => '$val', # necessary to use scaled value instead of raw data as subdir data
+        SubDirectory => { TagTable => 'Image::ExifTool::GoPro::GPS9' },
+    },
     GPSF => { #2 (gpmd)
         Name => 'GPSMeasureMode',
         PrintConv => {
@@ -199,7 +242,10 @@ my %addUnits = (
         Notes => 'gyroscope readings in rad/s',
         Binary => 1,
     },
+  # HCTL (GPMF) - seen: "Off" (fmt c)
+  # HDRV (GPMF) - seen: "N" (fmt c)
   # HFLG (APP6) - seen: 0
+  # HSGT (GPMF) - seen: 'OFF' (fmt c)
     ISOE => 'ISOSpeeds', #PH (gpmd)
     ISOG => { #2 (gpmd)
         Name => 'ImageSensorGain',
@@ -213,7 +259,9 @@ my %addUnits = (
         RawConv => '$val', # necessary to use scaled value instead of raw data as subdir data
         SubDirectory => { TagTable => 'Image::ExifTool::GoPro::KBAT' },
     },
-  # LINF (GPMF) - seen: LAJ7061916601668 (fmt c)
+  # KLNS (GPMF-BACK/FRNT) - double[5] (fmt d, Max)
+  # LINF (GPMF) - seen: LAJ7061916601668,C3341326002180,C33632245450981 (fmt c) (Lens INFormation?)
+  # LMOD (GPMF) - seen: 'NONE' (fmt F)
     LNED => { #PH (Karma)
         Name => 'LocalPositionNED',
         # UNIT=s,m,m,m,m/s,m/s,m/s
@@ -222,13 +270,20 @@ my %addUnits = (
         Binary => 1,
     },
     MAGN => 'Magnetometer', #1 (gpmd) (units of uT)
+  # MAPX (GPMF) - seen: 1 (fmt f)
+  # MAPY (GPMF) - seen: 1 (fmt f)
+  # MFOV (GPMF-BACK/FRNT) - seen: 100 (fmt d, Max)
     MINF => { #PH (GPMF - seen: HERO6 Black, fmt c)
         Name => 'Model',
         Groups => { 2 => 'Camera' },
         Description => 'Camera Model Name',
     },
-  # MTYP (GPMF) - seen: 0,1,11 [1 for time-lapse video, 11 for JPEG] (fmt B)
+  # MMOD (GPMF) - seen: 'STEREO' (fmt c)
+  # MTYP (GPMF) - seen: 0,1,5,11 [1 for time-lapse video, 5 for 360 video, 11 for JPEG] (fmt B)
   # MUID (GPMF) - seen: 3882563431 2278071152 967805802 411471936 0 0 0 0 (fmt L)
+  # MXCF (GPMF) - seen: 'x1' (fmt c)
+  # MYCF (GPMF) - seen: 'y1' (fmt c)
+  # ORDP (GPMF) - seen: 'Y' (fmt c)
     OREN => { #PH (GPMF - seen: 'U', fmt c)
         Name => 'AutoRotation',
         PrintConv => {
@@ -239,10 +294,16 @@ my %addUnits = (
     },
     # (most of the "P" tags are ProTune settings - PH)
     PHDR => 'HDRSetting', #PH (APP6 - seen: 0)
+  # PIMD (GPMF) - seen: 'AUTO' (fmt c)
     PIMN => 'AutoISOMin', #PH (GPMF - seen: 100, fmt L)
     PIMX => 'AutoISOMax', #PH (GPMF - seen: 1600, fmt L)
-  # PRAW (APP6) - seen: 0
+  # POLY (GPMF) - seen: '0 2.11120247840881 0.14325800538063 -1.030...' (fmt f)
+  # PRAW (APP6) - seen: 0, 'N', 'Y' (fmt c)
+  # PRCN (GPMF) - seen: 65 zeros (fmt B)
     PRES => 'PhotoResolution', #PH (APP6 - seen: '12MP_W')
+  # PRJT (APP6) - seen: 'GPRO','EACO' (fmt F, Hero8, Max)
+  # PRNA (GPMF) - seen 10 (fmt B)
+  # PRNU (GPMF) - seen 0 (fmt B)
     PRTN => { #PH (GPMF - seen: 'N', fmt c)
         Name => 'ProTune',
         PrintConv => {
@@ -254,6 +315,10 @@ my %addUnits = (
     PTEV => 'ExposureCompensation', #PH (GPMF - seen: '0.0', fmt c)
     PTSH => 'Sharpness', #PH (GPMF - seen: 'HIGH', fmt c)
     PTWB => 'WhiteBalance', #PH (GPMF - seen: 'AUTO', fmt c)
+  # PVUL (APP6) - seen: 'F' (fmt c, Hero8, Max)
+  # PWPR (GPMF) - seen: 'PERFORMANCE' (fmt c)
+  # PYCF (GPMF) - seen: '[r0,r1,r2,r3,r4,r5,r6]' (fmt c)
+  # RAMP (GPMF) - seen: empty string (fmt c)
     RATE => 'Rate', #PH (GPMF - seen: '0_5SEC', fmt c; APP6 - seen: '4_1SEC')
     RMRK => { #2 (gpmd)
         Name => 'Comments',
@@ -263,6 +328,7 @@ my %addUnits = (
         Name => 'ScaleFactor',
         Unknown => 1,
     },
+  # SCAP (GPMF) - seen: 'N' (fmt c)
     SCPR => { #PH (Karma) [stream was empty]
         Name => 'ScaledPressure',
         # UNIT=s,Pa,Pa,degC
@@ -270,6 +336,11 @@ my %addUnits = (
         # SCAL=1000 0.00999999977648258 0.00999999977648258 100
         %addUnits,
     },
+  # SCTM (GPMF) - seen 0 (fmt L)
+  # SFTR (GPMF-BACK/FRNT) - seen 0.999,1.00004 (fmt d, Max)
+  # SHFX (GPMF-GEOC) - seen 22.92 (fmt d, Max)
+  # SHFY (GPMF-GEOC) - seen 0.123 (fmt d, Max)
+  # SHFZ (GPMF-GEOC) - seen 36.06 (fmt d, Max)
     SHUT => { #2 (gpmd)
         Name => 'ExposureTimes',
         PrintConv => q{
@@ -291,6 +362,8 @@ my %addUnits = (
         ValueConv => '$self->Decode($val, "Latin")',
     },
   # SMTR (GPMF) - seen: 'N' (fmt c)
+  # SOFF (APP6) - seen: 0 (fmt L, Hero8, Max)
+  # SROT (GPMF) - seen 20.60 (fmt f, Max)
     STMP => { #1 (gpmd)
         Name => 'TimeStamp',
         ValueConv => '$val / 1e6',
@@ -328,11 +401,19 @@ my %addUnits = (
   # TOCK => { Name => 'OutTime', Unknown => 1, ValueConv => '$val/1000' }, #1 (gpmd)
     TSMP => { Name => 'TotalSamples', Unknown => 1 }, #2 (gpmd)
     TYPE => { Name => 'StructureType', Unknown => 1 }, #2 (gpmd,GPMF - eg 'LLLllfFff', fmt c)
+    TZON => { # (GPMF) - seen: 60 (fmt s)
+        Name => 'TimeZone',
+        PrintConv => 'Image::ExifTool::TimeZoneString($val)',
+    },
     UNIT => { #2 (gpmd) alternative units
         Name => 'Units',
         Unknown => 1,
         ValueConv => '$self->Decode($val, "Latin")',
     },
+    VERS => {
+        Name => 'MetadataVersion',
+        PrintConv => '$val =~ tr/ /./; $val',
+    },
     VFOV => { #PH (GPMF - seen: 'W', fmt c)
         Name => 'FieldOfView',
         PrintConv => {
@@ -342,21 +423,57 @@ my %addUnits = (
         },
     },
   # VLTA (GPMF) - seen: 78 ('N') (fmt B -- wrong format?)
+  # VFPS (GPMF) - seen: '24000 1001' (fmt L)
     VFRH => { #PH (Karma)
         Name => 'VisualFlightRulesHUD',
         BinaryData => 1,
         # UNIT=m/s,m/s,m,m/s,deg,%
         # TYPE=ffffsS
     },
-  # VLTE (GPMF) - seen: 'Y' (fmt c)
+  # VLTE (GPMF) - seen: 'Y','N' (fmt c)
+  # VRES (GPMF) - seen: '3840 3660' (fmt L)
     WBAL => 'ColorTemperatures', #PH (gpmd)
     WRGB => { #PH (gpmd)
         Name => 'WhiteBalanceRGB',
         Binary => 1,
     },
+  # ZFOV (APP6,GPMF) - seen: 148.34, 0 (fmt f, Hero8, Max)
+  # ZMPL (GPMF) - seen: 0.652929663658142 (fmt f)
+#
+# the following ref forum12825
+#
+    MUID => {
+        Name => 'MediaUniqueID',
+        PrintConv => q{
+            my @a = split ' ', $val;
+            $_ = sprintf('%.8x',$_) foreach @a;
+            return join('', @a);
+        },
+    },
+    EXPT => 'MaximumShutterAngle',
+    MTRX => 'AccelerometerMatrix',
+    ORIN => 'InputOrientation',
+    ORIO => 'OutputOrientation',
+    UNIF => 'InputUniformity',
+    SROT => 'SensorReadoutTime',
+    # the following are ref https://exiftool.org/forum/index.php?topic=15517.0
+    CORI => { Name => 'CameraOrientation', Binary => 1, Notes => 'quaternions 0-1' },
+    AALP => { Name => 'AudioLevel', Notes => 'dBFS' },
+    GPSA => 'GPSAltitudeSystem', # (eg. 'MSLV')
+    GRAV => { Name => 'GravityVector', Binary => 1 },
+    HUES => 'PrediminantHue',
+    IORI => { Name => 'ImageOrientation', Binary => 1, Notes => 'quaternions 0-1' },
+    # LRVO - ? Part of LRV Frame Skip
+    # LRVS - ? Part of LRV Frame Skip
+    # LSKP - LRV Frame Skip
+    # MSKP - MRV Frame Skip
+    MWET => 'MicrophoneWet',
+    SCEN => 'SceneClassification', # (SNOW,URBA,INDO,WATR,VEGE,BEAC + probability)
+    WNDM => 'WindProcessing',
+    YAVG => 'LumaAverage',
 );
 
-# GoPro GPS5 tags (ref 2) (Hero5,Hero6)
+# GoPro GPS5 tags (ref 2) (Hero5,Hero6,Hero9)
 %Image::ExifTool::GoPro::GPS5 = (
     PROCESS_PROC => \&ProcessString,
     GROUPS => { 1 => 'GoPro', 2 => 'Location' },
@@ -373,8 +490,65 @@ my %addUnits = (
         Name => 'GPSAltitude',
         PrintConv => '"$val m"',
     },
-    3 => 'GPSSpeed',   # (unit='m/s')
-    4 => 'GPSSpeed3D', # (unit='m/s')
+    3 => {
+        Name => 'GPSSpeed',
+        Notes => 'stored as m/s but converted to km/h when extracted',
+        ValueConv => '$val * 3.6',
+    },
+    4 => {
+        Name => 'GPSSpeed3D',
+        Notes => 'stored as m/s but converted to km/h when extracted',
+        ValueConv => '$val * 3.6',
+    },
+);
+
+# GoPro GPS9 tags (Hero13)
+%Image::ExifTool::GoPro::GPS9 = (
+    PROCESS_PROC => \&ProcessString,
+    GROUPS => { 1 => 'GoPro', 2 => 'Location' },
+    VARS => { HEX_ID => 0, ID_LABEL => 'Index' },
+    0 => { # (unit='deg')
+        Name => 'GPSLatitude',
+        PrintConv => 'Image::ExifTool::GPS::ToDMS($self, $val, 1, "N")',
+    },
+    1 => { # (unit='deg')
+        Name => 'GPSLongitude',
+        PrintConv => 'Image::ExifTool::GPS::ToDMS($self, $val, 1, "E")',
+    },
+    2 => { # (unit='m')
+        Name => 'GPSAltitude',
+        PrintConv => '"$val m"',
+    },
+    3 => {
+        Name => 'GPSSpeed',
+        Notes => 'stored as m/s but converted to km/h when extracted',
+        ValueConv => '$val * 3.6',
+    },
+    4 => {
+        Name => 'GPSSpeed3D',
+        Notes => 'stored as m/s but converted to km/h when extracted',
+        ValueConv => '$val * 3.6',
+    },
+    5 => { # days since 2000
+        Name => 'GPSDays',
+        RawConv => '$$self{GPSDays} = $val; undef',
+        Hidden => 1,
+    },
+    6 => { # seconds of date/time
+        Name => 'GPSDateTime',
+        Groups => { 2 => 'Time' },
+        # (10957 days from Jan 1 1970 to Jan 1 2000)
+        RawConv => 'ConvertUnixTime(($$self{GPSDays} + 10957) * 24 * 3600 + $val, undef, 3)',
+        PrintConv => '$self->ConvertDateTime($val)',
+    },
+    7 => 'GPSDOP',
+    8 => {
+        Name => 'GPSMeasureMode', #PH (NC)
+        PrintConv => {
+            2 => '2-Dimensional Measurement',
+            3 => '3-Dimensional Measurement',
+        },
+    },
 );
 
 # GoPro GPRI tags (ref PH) (Karma)
@@ -469,7 +643,7 @@ my %addUnits = (
     PROCESS_PROC => \&Image::ExifTool::ProcessBinaryData,
     NOTES => q{
         Tags extracted from the MP4 "fdsc" timed metadata when the L<ExtractEmbedded|../ExifTool.html#ExtractEmbedded>
-        option is used.
+        (-ee) option is used.
     },
     0x08 => { Name => 'FirmwareVersion',    Format => 'string[15]' },
     0x17 => { Name => 'SerialNumber',       Format => 'string[16]' },
@@ -542,7 +716,7 @@ sub ScaleValues($$)
 sub AddUnits($$$)
 {
     my ($et, $val, $tag) = @_;
-    if ($et and $$et{TAG_EXTRA}{$tag} and $$et{TAG_EXTRA}{$tag}{Units}) {
+    if ($et and $$et{TAG_EXTRA}{$tag}{Units}) {
         my $u = $$et{TAG_EXTRA}{$tag}{Units};
         $u = [ $u ] unless ref $u eq 'ARRAY';
         my @a = split ' ', $val;
@@ -583,6 +757,7 @@ sub ProcessString($$$)
 # Process GoPro metadata (gpmd samples, GPMF box, or APP6) (ref PH/1/2)
 # Inputs: 0) ExifTool object ref, 1) dirInfo ref, 2) tag table ref
 # Returns: 1 on success
+# - with hack to check for encrypted text in gpmd data (Rove Stealth 4K)
 sub ProcessGoPro($$$)
 {
     my ($et, $dirInfo, $tagTablePtr) = @_;
@@ -685,7 +860,7 @@ metadata from GoPro MP4 videos.
 
 =head1 AUTHOR
 
-Copyright 2003-2019, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2024, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
