@@ -16,7 +16,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.33';
+$VERSION = '1.42';
 
 sub ProcessJpeg2000Box($$$);
 sub ProcessJUMD($$$);
@@ -34,6 +34,9 @@ my %resolutionUnit = (
      6 => 'um',
 );
 
+# top-level boxes containing image data
+my %isImageData = ( jp2c=>1, jbrd=>1, jxlp=>1, jxlc=>1 );
+
 # map of where information is written in JPEG2000 image
 my %jp2Map = (
     IPTC         => 'UUID-IPTC',
@@ -86,12 +89,14 @@ my %uuid = (
 # JPEG2000 codestream markers (ref ISO/IEC FCD15444-1/2)
 my %j2cMarker = (
     0x4f => 'SOC', # start of codestream
+  # 0x50 - seen in JPH codestream
     0x51 => 'SIZ', # image and tile size
     0x52 => 'COD', # coding style default
     0x53 => 'COC', # coding style component
     0x55 => 'TLM', # tile-part lengths
     0x57 => 'PLM', # packet length, main header
     0x58 => 'PLT', # packet length, tile-part header
+  # 0x59 - seen in JPH codestream
     0x5c => 'QCD', # quantization default
     0x5d => 'QCC', # quantization component
     0x5e => 'RGN', # region of interest
@@ -125,9 +130,24 @@ my %j2cMarker = (
     WRITE_PROC => \&ProcessJpeg2000Box,
     PREFERRED => 1, # always add these tags when writing
     NOTES => q{
-        The tags below are found in JPEG 2000 images and the JUMBF metadata in JPEG
-        images, but not all of these are extracted.  Note that ExifTool currently
-        writes only EXIF, IPTC and XMP tags in Jpeg2000 images.
+        The tags below are found in JPEG 2000 images and the C2PA CAI JUMBF metadata
+        in various file types (see below).  Note that ExifTool currently writes only
+        EXIF, IPTC and XMP tags in Jpeg2000 images, and EXIF and XMP in JXL images. 
+        ExifTool will read/write Brotli-compressed EXIF and XMP in JXL images, but
+        the API L<Compress|../ExifTool.html#Compress> option must be set to create new EXIF and XMP in compressed
+        format.
+
+        C2PA (Coalition for Content Provenance and Authenticity) CAI (Content
+        Authenticity Initiative) JUMBF (JPEG Universal Metadata Box Format) metdata
+        is currently extracted from JPEG, PNG, TIFF-based (eg. TIFF, DNG),
+        QuickTime-based (eg. MP4, MOV, HEIF, AVIF), RIFF-based (eg. WAV, AVI, WebP),
+        PDF, SVG and GIF files, and ID3v2 metadata.  The suggested ExifTool
+        command-line arguments for reading C2PA metadata are C<-jumbf:all -G3 -b -j
+        -u -struct>.  This metadata may be deleted from writable JPEG, PNG, WebP,
+        TIFF-based, and QuickTime-based files by deleting the JUMBF group with
+        C<-jumbf:all=>.  The C2PA JUMBF metadata may be extracted as a block via the
+        JUMBF tag.  See L<https://c2pa.org/specifications/> for the C2PA
+        specification.
     },
 #
 # NOTE: ONLY TAGS WITH "Format" DEFINED ARE EXTRACTED!
@@ -259,7 +279,7 @@ my %j2cMarker = (
     uuid => [
         {
             Name => 'UUID-EXIF',
-            # (this is the EXIF that we create)
+            # (this is the EXIF that we create in JP2)
             Condition => '$$valPt=~/^JpgTiffExif->JP2(?!Exif\0\0)/',
             SubDirectory => {
                 TagTable => 'Image::ExifTool::Exif::Main',
@@ -295,7 +315,7 @@ my %j2cMarker = (
         },
         {
             Name => 'UUID-IPTC',
-            # (this is the IPTC that we create)
+            # (this is the IPTC that we create in JP2)
             Condition => '$$valPt=~/^\x33\xc7\xa4\xd2\xb8\x1d\x47\x23\xa0\xba\xf1\xa3\xe0\x97\xad\x38/',
             SubDirectory => {
                 TagTable => 'Image::ExifTool::IPTC::Main',
@@ -339,13 +359,6 @@ my %j2cMarker = (
                 Start => '$valuePtr + 16',
             },
         },
-        {
-            Name => 'UUID-Signature',  # (seen in JUMB data of JPEG images)
-            # (may be able to remove this when JUMBF specification is finalized)
-            Condition => '$$valPt=~/^casg\x00\x11\x00\x10\x80\x00\x00\xaa\x00\x38\x9b\x71/',
-            Format => 'undef',
-            ValueConv => 'substr($val,16)',
-        },
         {
             Name => 'UUID-C2PAClaimSignature',  # (seen in incorrectly-formatted JUMB data of JPEG images)
             # (may be able to remove this when JUMBF specification is finalized)
@@ -355,6 +368,13 @@ my %j2cMarker = (
                 Start => '$valuePtr + 16',
             },
         },
+        {
+            Name => 'UUID-Signature',  # (seen in JUMB data of JPEG images)
+            # (may be able to remove this when JUMBF specification is finalized)
+            Condition => '$$valPt=~/^casg\x00\x11\x00\x10\x80\x00\x00\xaa\x00\x38\x9b\x71/',
+            Format => 'undef',
+            ValueConv => 'substr($val,16)',
+        },
         {
             Name => 'UUID-Unknown',
         },
@@ -402,7 +422,7 @@ my %j2cMarker = (
         Flags => [ 'Binary', 'Protected' ],
         SubDirectory => { TagTable => 'Image::ExifTool::CBOR::Main' },
     },
-    bfdb => { # used in JUMBF (see  # (used when tag is renamed according to JUMDLabel)
+    bfdb => { # used in JUMBF
         Name => 'BinaryDataType',
         Notes => 'JUMBF, MIME type and optional file name',
         Format => 'undef',
@@ -437,6 +457,15 @@ my %j2cMarker = (
         },
         RawConv => 'Image::ExifTool::Jpeg2000::ProcessJXLCodestream($self,\$val); undef',
     },
+    jxlp => {
+        Name => 'PartialJXLCodestream',
+        Format => 'undef',
+        Notes => q{
+            Partial codestreams in JPEG XL image.  Currently processed only to determine
+            ImageSize
+        },
+        RawConv => 'Image::ExifTool::Jpeg2000::ProcessJXLCodestream($self,\$val); undef',
+    },
     Exif => {
         Name => 'EXIF',
         SubDirectory => {
@@ -447,6 +476,38 @@ my %j2cMarker = (
             Start => '$valuePtr + 4 + (length($$dataPt)-$valuePtr > 4 ? unpack("N", $$dataPt) : 0)',
         },
     },
+    hrgm => {
+        Name => 'GainMapImage',
+        Groups => { 2 => 'Preview' },
+        Format => 'undef',
+        Binary => 1,
+    },
+    brob => [{ # Brotli-encoded metadata (see https://libjxl.readthedocs.io/en/latest/api_decoder.html)
+        Name => 'BrotliXMP',
+        Condition => '$$valPt =~ /^xml /i',
+        SubDirectory => {
+            TagTable => 'Image::ExifTool::XMP::Main',
+            ProcessProc => \&ProcessBrotli,
+            WriteProc => \&ProcessBrotli,
+            # (don't set DirName to 'XMP' because this would enable a block write of raw XMP)
+        },
+    },{
+        Name => 'BrotliEXIF',
+        Condition => '$$valPt =~ /^exif/i',
+        SubDirectory => {
+            TagTable => 'Image::ExifTool::Exif::Main',
+            ProcessProc => \&ProcessBrotli,
+            WriteProc => \&ProcessBrotli,
+            # (don't set DirName to 'EXIF' because this would enable a block write of raw EXIF)
+        },
+    },{
+        Name => 'BrotliJUMB',
+        Condition => '$$valPt =~ /^jumb/i',
+        SubDirectory => {
+            TagTable => 'Image::ExifTool::Jpeg2000::Main',
+            ProcessProc => \&ProcessBrotli,
+        },
+    }],
 );
 
 %Image::ExifTool::Jpeg2000::ImageHeader = (
@@ -502,6 +563,7 @@ my %j2cMarker = (
             'jpm ' => 'JPEG 2000 Compound Image (.JPM)',  # image/jpm
             'jpx ' => 'JPEG 2000 with extensions (.JPX)', # image/jpx
             'jxl ' => 'JPEG XL Image (.JXL)',             # image/jxl
+            'jph ' => 'High-throughput JPEG 2000 (.JPH)', # image/jph
         },
     },
     1 => {
@@ -512,6 +574,7 @@ my %j2cMarker = (
     2 => {
         Name => 'CompatibleBrands',
         Format => 'undef[$size-8]',
+        List => 1, # (for documentation only)
         # ignore any entry with a null, and return others as a list
         ValueConv => 'my @a=($val=~/.{4}/sg); @a=grep(!/\0/,@a); \@a',
     },
@@ -665,7 +728,6 @@ my %j2cMarker = (
         {
             Name => 'ColorSpecData',
             Format => 'undef[$size-3]',
-            Writable => 'undef',
             Protected => 1,
             Binary => 1,
         },
@@ -689,6 +751,7 @@ my %j2cMarker = (
         },
         # seen:
         # cacb/cast/caas/cacl/casg/json-00110010800000aa00389b71
+        #   (also brob- but not yet tested)
         # 6579d6fbdba2446bb2ac1b82feeb89d1 - JPEG image
     },
     'label' => { Name => 'JUMDLabel' },
@@ -762,6 +825,7 @@ sub ProcessJUMD($$$)
             $name =~ tr/-_a-zA-Z0-9//dc;    # remove other illegal characters
             $name =~ s/__/_/;               # collapse double underlines
             $name = ucfirst $name;          # capitalize first letter
+            $name =~ s/C2pa/C2PA/;          # capitalize C2PA
             $name = "Tag$name" if length($name) < 2; # must at least 2 characters long
             $$et{JUMBFLabel} = $name;
         }
@@ -795,6 +859,17 @@ sub ProcessJUMD($$$)
     return 1;
 }
 
+#------------------------------------------------------------------------------
+# Warn about error in Brotli compression/decompression
+# Inputs: 0) ExifTool ref, 1) box type, 2) true for decoding (Uncompress)
+sub BrotliWarn($$;$)
+{
+    my ($et, $type, $uncompress) = @_;
+    my ($enc, $mod) = $uncompress ? qw(decoding Uncompress) : qw(encoding Compress);
+    $et->WarnOnce("Error $enc '${type}' brob box");
+    $et->WarnOnce("Try updating to IO::${mod}::Brotli 0.004 or later");
+}
+
 #------------------------------------------------------------------------------
 # Create new JPEG 2000 boxes when writing
 # (Currently only supports adding top-level Writable JPEG2000 tags and certain UUID boxes)
@@ -836,12 +911,31 @@ sub CreateNewBoxes($$)
             $tagTable = GetTagTable('Image::ExifTool::XMP::Main') if $dir eq 'XMP';
             my %dirInfo = (
                 DirName => $dir,
-                Parent => 'JP2',
+                Parent => $tag,
             );
+            my $compress = $et->Options('Compress');
+            $dirInfo{Compact} = 1 if $$et{IsJXL} and $compress;
             my $newdir = $et->WriteDirectory(\%dirInfo, $tagTable, $$subdir{WriteProc});
             if (defined $newdir and length $newdir) {
                 # not sure why, but EXIF box is padded with leading 0's in my sample
                 my $pad = $dirName eq 'Exif' ? "\0\0\0\0" : '';
+                if ($$et{IsJXL} and $compress) {
+                    # create as Brotli-compressed metadata
+                    if (eval { require IO::Compress::Brotli }) {
+                        my $compressed;
+                        eval { $compressed = IO::Compress::Brotli::bro($pad . $newdir) };
+                        if ($@ or not $compressed) {
+                            BrotliWarn($et, $dirName);
+                        } else {
+                            $et->VPrint(0, "  Writing Brotli-compressed $dir\n");
+                            $newdir = $compressed;
+                            $pad = $tag;
+                            $tag = 'brob';
+                        }
+                    } else {
+                        $et->WarnOnce('Install IO::Compress::Brotli to create Brotli-compressed metadata');
+                    }
+                }
                 my $boxhdr = pack('N', length($newdir) + length($pad) + 8) . $tag;
                 Write($outfile, $boxhdr, $pad, $newdir) or return 0;
                 next;
@@ -927,10 +1021,24 @@ sub ProcessJpeg2000Box($$$)
     my $dirLen = $$dirInfo{DirLen} || 0;
     my $dirStart = $$dirInfo{DirStart} || 0;
     my $base = $$dirInfo{Base} || 0;
-    my $raf = $$dirInfo{RAF};
     my $outfile = $$dirInfo{OutFile};
+    my $dirName = $$dirInfo{DirName} || '';
     my $dirEnd = $dirStart + $dirLen;
-    my ($err, $outBuff, $verbose, $doColour);
+    my ($err, $outBuff, $verbose, $doColour, $hash, $raf);
+
+    if ($dataPt) {
+        # save C2PA JUMBF as a block if requested
+        if ($dirName eq 'JUMBF' and $$et{REQ_TAG_LOOKUP}{jumbf} and not $$dirInfo{NoBlockSave}) {
+            if ($dirStart or $dirLen ne length($$dataPt)) {
+                my $dat = substr($$dataPt, $dirStart, $dirLen);
+                $et->FoundTag(JUMBF => \$dat);
+            } else {
+                $et->FoundTag(JUMBF => $dataPt);
+            }
+        }
+    } else {
+        $raf = $$dirInfo{RAF};  # read from RAF
+    }
 
     if ($outfile) {
         unless ($raf) {
@@ -939,7 +1047,7 @@ sub ProcessJpeg2000Box($$$)
             $outfile = \$outBuff;
         }
         # determine if we will be writing colr box
-        if ($$dirInfo{DirName} and $$dirInfo{DirName} eq 'JP2Header') {
+        if ($dirName eq 'JP2Header') {
             $doColour = 2 if defined $et->GetNewValue('ColorSpecMethod') or $et->GetNewValue('ICC_Profile') or
                              defined $et->GetNewValue('ColorSpecPrecedence') or defined $et->GetNewValue('ColorSpace') or
                              defined $et->GetNewValue('ColorSpecApproximation') or defined $et->GetNewValue('ColorSpecData');
@@ -947,7 +1055,9 @@ sub ProcessJpeg2000Box($$$)
     } else {
         # (must not set verbose flag when writing!)
         $verbose = $$et{OPTIONS}{Verbose};
-        $et->VerboseDir($$dirInfo{DirName}) if $verbose;
+        $et->VerboseDir($dirName) if $verbose;
+        # do hash if requested, but only for top-level image data
+        $hash = $$et{ImageDataHash} if $raf;
     }
     # loop through all contained boxes
     my ($pos, $boxLen, $lastBox);
@@ -971,6 +1081,11 @@ sub ProcessJpeg2000Box($$$)
         }
         $boxLen = unpack("x$pos N",$$dataPt);   # (length includes header and data)
         $boxID = substr($$dataPt, $pos+4, 4);
+        # (ftbl box contains flst boxes with absolute file offsets, not currently handled)
+        if ($outfile and $boxID eq 'ftbl') {
+            $et->Error("Can't yet handle fragmented JPX files");
+            return -1;
+        }
         # remove old colr boxes if necessary
         if ($doColour and $boxID eq 'colr') {
             if ($doColour == 1) { # did we successfully write the new colr box?
@@ -1007,9 +1122,14 @@ sub ProcessJpeg2000Box($$$)
                     while ($raf->Read($buff, 65536)) {
                         Write($outfile, $buff) or $err = 1;
                     }
-                } elsif ($verbose) {
-                    my $msg = sprintf("offset 0x%.4x to end of file", $dataPos + $base + $pos);
-                    $et->VPrint(0, "$$et{INDENT}- Tag '${boxID}' ($msg)\n");
+                } else {
+                    if ($verbose) {
+                        my $msg = sprintf("offset 0x%.4x to end of file", $dataPos + $base + $pos);
+                        $et->VPrint(0, "$$et{INDENT}- Tag '${boxID}' ($msg)\n");
+                    }
+                    if ($hash and $isImageData{$boxID}) {
+                        $et->ImageDataHash($raf, undef, $boxID);
+                    }
                 }
                 last;   # (ignore the rest of the file when reading)
             }
@@ -1026,6 +1146,8 @@ sub ProcessJpeg2000Box($$$)
                     Write($outfile, $$dataPt) or $err = 1;
                     $raf->Read($buff,$boxLen) == $boxLen or $err = '', last;
                     Write($outfile, $buff) or $err = 1;
+                } elsif ($hash and $isImageData{$boxID}) {
+                    $et->ImageDataHash($raf, $boxLen, $boxID);
                 } else {
                     $raf->Seek($boxLen, 1) or $err = 'Seek error', last;
                 }
@@ -1038,6 +1160,10 @@ sub ProcessJpeg2000Box($$$)
             # read the box data
             $dataPos = $raf->Tell() - $base;
             $raf->Read($buff,$boxLen) == $boxLen or $err = '', last;
+            if ($hash and $isImageData{$boxID}) {
+                $hash->add($buff);
+                $et->VPrint(0, "$$et{INDENT}(ImageDataHash: $boxLen bytes of $boxID data)\n");
+            }
             $valuePtr = 0;
             $dataLen = $boxLen;
         } elsif ($pos + $boxLen > $dirEnd) {
@@ -1078,7 +1204,7 @@ sub ProcessJpeg2000Box($$$)
         # create new tag for JUMBF data values with name corresponding to JUMBFLabel
         if ($tagInfo and $$et{JUMBFLabel} and (not $$tagInfo{SubDirectory} or $$tagInfo{BlockExtract})) {
             $tagInfo = { %$tagInfo, Name => $$et{JUMBFLabel} . ($$tagInfo{JUMBF_Suffix} || '') };
-            delete $$tagInfo{Description};
+            ($$tagInfo{Description} = Image::ExifTool::MakeDescription($$tagInfo{Name})) =~ s/C2 PA/C2PA/;
             AddTagToTable($tagTablePtr, '_JUMBF_' . $$et{JUMBFLabel}, $tagInfo);
             delete $$tagInfo{Protected}; # (must do this so -j -b returns JUMBF binary data)
             $$tagInfo{TagID} = $boxID;
@@ -1122,19 +1248,66 @@ sub ProcessJpeg2000Box($$$)
             $subdirInfo{DirName} =~ s/^UUID-//;
             my $subTable = GetTagTable($$subdir{TagTable}) || $tagTablePtr;
             if ($outfile) {
-                # remove this directory from our create list
-                delete $$et{AddJp2Dirs}{$$tagInfo{Name}};   # (eg. 'EXIF' or 'XMP')
-                delete $$et{AddJp2Dirs}{$boxID};            # (eg. 'Exif' or 'xml ')
+                # (special case for brob box, which may be EXIF or XMP)
+                my $fakeID = $boxID;
+                if ($boxID eq 'brob') {
+                    # I have seen 'brob' ID's with funny cases, so standardize these
+                    $fakeID = 'xml ' if $$dataPt =~ /^xml /i;
+                    $fakeID = 'Exif' if $$dataPt =~ /^Exif/i;
+                }
                 my $newdir;
                 # only edit writable UUID, Exif and jp2h boxes
-                if ($uuid or $boxID eq 'Exif' or ($boxID eq 'xml ' and $$et{IsJXL}) or
+                if ($uuid or $fakeID eq 'Exif' or ($fakeID eq 'xml ' and $$et{IsJXL}) or
                     ($boxID eq 'jp2h' and $$et{EDIT_DIRS}{jp2h}))
                 {
+                    my $compress = $et->Options('Compress');
+                    $subdirInfo{Parent} = $fakeID;
+                    $subdirInfo{Compact} = 1 if $compress and $$et{IsJXL};
                     $newdir = $et->WriteDirectory(\%subdirInfo, $subTable, $$subdir{WriteProc});
                     next if defined $newdir and not length $newdir; # next if deleting the box
+                    # compress JXL EXIF or XMP metadata if requested
+                    if (defined $newdir and $$et{IsJXL} and defined $compress and
+                        ($fakeID eq 'Exif' or $fakeID eq 'xml '))
+                    {
+                        if ($compress and $boxID ne 'brob') {
+                            # rewrite as a Brotli-compressed 'brob' box
+                            if (eval { require IO::Compress::Brotli }) {
+                                my $pad = $boxID eq 'Exif' ? "\0\0\0\0" : '';
+                                my $compressed;
+                                eval { $compressed = IO::Compress::Brotli::bro($pad . $newdir) };
+                                if ($@ or not $compressed) {
+                                    BrotliWarn($et, $boxID);
+                                } else {
+                                    $et->VPrint(0, "  Writing Brotli-compressed $boxID\n");
+                                    $newdir = $boxID . $compressed;
+                                    $boxID = 'brob';
+                                    $subdirStart = $valuePtr = 0;
+                                    ++$$et{CHANGED};
+                                }
+                            } else {
+                                $et->WarnOnce('Install IO::Compress::Brotli to write Brotli-compressed metadata');
+                            }
+                        } elsif (not $compress and $boxID eq 'brob') {
+                            # (in this case, ProcessBrotli has returned uncompressed data,
+                            #  so change to the uncompressed 'xml ' or 'Exif' box type)
+                            $et->VPrint(0, "  Writing uncompressed $fakeID\n");
+                            $boxID = $fakeID;
+                            $subdirStart = $valuePtr = 0;
+                            ++$$et{CHANGED};
+                        }
+                    }
                 } elsif (defined $uuid) {
                     $et->Warn("Not editing $$tagInfo{Name} box", 1);
                 }
+                # remove this directory from our create list
+                delete $$et{AddJp2Dirs}{$fakeID};               # (eg. 'Exif' or 'xml ')
+                if ($boxID eq 'brob') {
+                    # (can't make tag Name 'XMP' or 'Exif' for Brotli-compressed tags because it
+                    #  would break the logic in WriteDirectory(), so we do a lookup here instead)
+                    delete $$et{AddJp2Dirs}{{'xml '=>'XMP','Exif'=>'EXIF'}->{$fakeID}};
+                } else {
+                    delete $$et{AddJp2Dirs}{$$tagInfo{Name}};   # (eg. 'EXIF' or 'XMP')
+                }
                 # use old box data if not changed
                 defined $newdir or $newdir = substr($$dataPt, $subdirStart, $subdirLen);
                 my $prefixLen = $subdirStart - $valuePtr;
@@ -1165,7 +1338,7 @@ sub ProcessJpeg2000Box($$$)
             if (defined $val) {
                 my $key = $et->FoundTag($tagInfo, $val);
                 # save Rational value
-                $$et{RATIONAL}{$key} = $rational if defined $rational and defined $key;
+                $$et{TAG_EXTRA}{$key}{Rational} = $rational if defined $rational and defined $key;
             }
         } elsif ($outfile) {
             my $boxhdr = pack('N', $boxLen + 8) . $boxID;
@@ -1210,19 +1383,108 @@ sub GetBits($$)
     return $v;
 }
 
+#------------------------------------------------------------------------------
+# Read/write Brotli-encoded metadata
+# Inputs: 0) ExifTool ref, 1) dirInfoRef, 2) tag table ref
+# Returns: 1 on success when reading, or new data when writing (undef if unchanged)
+# (ref https://libjxl.readthedocs.io/en/latest/api_decoder.html)
+sub ProcessBrotli($$$)
+{
+    my ($et, $dirInfo, $tagTablePtr) = @_;
+    my $dataPt = $$dirInfo{DataPt};
+
+    return 0 unless length($$dataPt) > 4;
+
+    my $isWriting = $$dirInfo{IsWriting};
+    my $type = substr($$dataPt, 0, 4);
+    $et->VerboseDir("Decrypted Brotli '${type}'") unless $isWriting;
+    my %knownType = ( exif => 'Exif', 'xml ' => 'xml ', jumb => 'jumb' );
+    my $stdType = $knownType{lc $type};
+    unless ($stdType) {
+        $et->Warn('Unknown Brotli box type', 1);
+        return 1;
+    }
+    if ($type ne $stdType) {
+        $et->Warn("Incorrect case for Brotli '${type}' data (should be '${stdType}')");
+        $type = $stdType;
+    }
+    if (eval { require IO::Uncompress::Brotli }) {
+        if ($isWriting and not eval { require IO::Compress::Brotli }) {
+            $et->WarnOnce('Install IO::Compress::Brotli to write Brotli-compressed metadata');
+            return undef;
+        }
+        my $compress = $et->Options('Compress');
+        my $verbose = $isWriting ? 0 : $et->Options('Verbose');
+        my $dat = substr($$dataPt, 4);
+        eval { $dat = IO::Uncompress::Brotli::unbro($dat, 100000000) };
+        $@ and BrotliWarn($et, $type, 1), return 1;
+        $verbose > 2 and $et->VerboseDump(\$dat, Prefix => $$et{INDENT} . '  ');
+        my %dirInfo = ( DataPt => \$dat );
+        if ($type eq 'xml ') {
+            $dirInfo{DirName} = 'XMP'; # (necessary for block read/write)
+            require Image::ExifTool::XMP;
+            if ($isWriting) {
+                $dirInfo{Compact} = 1 if $compress;  # (no need to add padding if writing compressed)
+                $dat = $et->WriteDirectory(\%dirInfo, $tagTablePtr);
+            } else {
+                Image::ExifTool::XMP::ProcessXMP($et, \%dirInfo, $tagTablePtr);
+            }
+        } elsif ($type eq 'Exif') {
+            $dirInfo{DirName} = 'EXIF'; # (necessary for block read/write)
+            $dirInfo{DirStart} = 4 + (length($dat) > 4 ? unpack("N", $dat) : 0);
+            if ($dirInfo{DirStart} > length $dat) {
+                $et->Warn("Corrupted Brotli '${type}' data");
+            } elsif ($isWriting) {
+                $dat = $et->WriteDirectory(\%dirInfo, $tagTablePtr, \&Image::ExifTool::WriteTIFF);
+                # add back header word
+                $dat = "\0\0\0\0" . $dat if defined $dat and length $dat;
+            } else {
+                $et->ProcessTIFF(\%dirInfo, $tagTablePtr);
+            }
+        } elsif ($type eq 'jumb') {
+            return undef if $isWriting; # (can't yet write JUMBF)
+            Image::ExifTool::Jpeg2000::ProcessJUMB($et, \%dirInfo, $tagTablePtr); # (untested)
+        }
+        if ($isWriting) {
+            return undef unless defined $dat;
+            # rewrite as uncompressed if Compress option is set to 0 (or '')
+            return $dat if defined $compress and not $compress;
+            eval { $dat = IO::Compress::Brotli::bro($dat) };
+            $@ and BrotliWarn($et, $type), return undef;
+            $et->VPrint(0, "  Writing Brotli-compressed $type\n");
+            return $type . $dat;
+        }
+    } else {
+        $et->WarnOnce('Install IO::Uncompress::Brotli to decode Brotli-compressed metadata');
+        return undef if $isWriting;
+    }
+    return 1;
+}
+
 #------------------------------------------------------------------------------
 # Extract parameters from JPEG XL codestream [unverified!]
 # Inputs: 0) ExifTool ref, 1) codestream ref
-# Returns: 1
+# Returns: 1 on success
 sub ProcessJXLCodestream($$)
 {
     my ($et, $dataPt) = @_;
-    # add padding if necessary to avoid unpacking past end of data
-    if (length $$dataPt < 14) {
-        my $tmp = $$dataPt . ("\0" x 14);
-        $dataPt = \$tmp;
+
+    return 0 unless $$dataPt =~ /^(\0\0\0\0)?\xff\x0a/; # validate codestream
+    # ignore if already extracted (ie. subsequent jxlp boxes)
+    return 0 if $$et{ProcessedJXLCodestream};
+    $$et{ProcessedJXLCodestream} = 1;
+    # work with first 64 bytes of codestream data
+    # (and add padding if necessary to avoid unpacking past end of data)
+    my $dat;
+    if (length $$dataPt > 64) {
+        $dat = substr($$dataPt, 0, 64);
+    } elsif (length $$dataPt < 18) {
+        $dat = $$dataPt . ("\0" x 18); # (so we'll have a minimum 14 bytes to work with)
+    } else {
+        $dat = $$dataPt;
     }
-    my @a = unpack 'x2C12', $$dataPt;
+    $dat =~ s/^\0\0\0\0//;  # remove jxlp header word
+    my @a = unpack 'x2C12', $dat;
     my ($x, $y);
     my $small = GetBits(\@a, 1);
     if ($small) {
@@ -1246,6 +1508,28 @@ sub ProcessJXLCodestream($$)
     return 1;
 }
 
+#------------------------------------------------------------------------------
+# Read/write meta information from a C2PA/JUMBF file
+# Inputs: 0) ExifTool object reference, 1) dirInfo reference
+# Returns: 1 on success, 0 if this wasn't a valid JUMBF file
+sub ProcessJUMBF($$)
+{
+    my ($et, $dirInfo) = @_;
+    my $raf = $$dirInfo{RAF};
+    my $hdr;
+
+    # check to be sure this is a valid JPG2000 file
+    return 0 unless $raf->Read($hdr,20) == 20 and $raf->Seek(0,0);
+    return 0 unless $hdr =~ /^.{4}jumb\0.{3}jumd(.{4})/;
+    $et->SetFileType($1 eq 'c2pa' ? 'C2PA' : 'JUMBF');
+    my %dirInfo = (
+        RAF => $raf,
+        DirName => 'JUMBF',
+    );
+    my $tagTablePtr = GetTagTable('Image::ExifTool::Jpeg2000::Main');
+    return $et->ProcessDirectory(\%dirInfo, $tagTablePtr);
+}
+
 #------------------------------------------------------------------------------
 # Read/write meta information from a JPEG 2000 image
 # Inputs: 0) ExifTool object reference, 1) dirInfo reference
@@ -1260,7 +1544,7 @@ sub ProcessJP2($$)
 
     # check to be sure this is a valid JPG2000 file
     return 0 unless $raf->Read($hdr,12) == 12;
-    unless ($hdr eq "\0\0\0\x0cjP  \x0d\x0a\x87\x0a" or     # (ref 1)
+    unless ($hdr eq "\0\0\0\x0cjP  \x0d\x0a\x87\x0a" or       # (ref 1)
             $hdr eq "\0\0\0\x0cjP\x1a\x1a\x0d\x0a\x87\x0a" or # (ref 2)
             $$et{IsJXL})
     {
@@ -1296,6 +1580,7 @@ sub ProcessJP2($$)
             $fileType = 'JPX' if $1 eq 'jpx ';
             $fileType = 'JPM' if $1 eq 'jpm ';
             $fileType = 'JXL' if $1 eq 'jxl ';
+            $fileType = 'JPH' if $1 eq 'jph ';
         }
         $raf->Seek(-length($buff), 1) if defined $buff;
         $et->SetFileType($fileType);
@@ -1311,7 +1596,7 @@ sub ProcessJP2($$)
 }
 
 #------------------------------------------------------------------------------
-# Read meta information from a JPEG XL image
+# Read/write meta information in a JPEG XL image
 # Inputs: 0) ExifTool object reference, 1) dirInfo reference
 # Returns: 1 on success, 0 if this wasn't a valid JPEG XL file, -1 on write error
 sub ProcessJXL($$)
@@ -1337,9 +1622,12 @@ sub ProcessJXL($$)
             $$et{IsJXL} = 2;
             my $buff = "\0\0\0\x0cJXL \x0d\x0a\x87\x0a\0\0\0\x14ftypjxl \0\0\0\0jxl ";
             # add metadata to empty ISO BMFF container
-            $$dirInfo{RAF} = new File::RandomAccess(\$buff);
+            $$dirInfo{RAF} = File::RandomAccess->new(\$buff);
         } else {
             $et->SetFileType('JXL Codestream','image/jxl', 'jxl');
+            if ($$et{ImageDataHash} and $raf->Seek(0,0)) {
+                $et->ImageDataHash($raf, undef, 'JXL');
+            }
             return ProcessJXLCodestream($et, \$hdr);
         }
     } else {
@@ -1382,7 +1670,7 @@ files.
 
 =head1 AUTHOR
 
-Copyright 2003-2023, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2024, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
